@@ -26,6 +26,7 @@ DEFAULT_CONSUMER_TIMEOUT_MS = 10000
 DEFAULT_SESSION_TIMEOUT_MS = 30000
 DEFAULT_HEARTBEAT_INTERVAL_MS = 10000
 DEFAULT_MAX_POLL_INTERVAL_MS = 300000
+DEFAULT_MAX_POLL_RECORDS = 500
 DEFAULT_ENCODING = 'utf-8'
 DEFAULT_LOCAL_STORE_DIR = os.path.join(os.getcwd(), 'tap-kafka-local-store')
 
@@ -80,6 +81,7 @@ def generate_config(args_config):
         'consumer_timeout_ms': args_config.get('consumer_timeout_ms', DEFAULT_CONSUMER_TIMEOUT_MS),
         'session_timeout_ms': args_config.get('session_timeout_ms', DEFAULT_SESSION_TIMEOUT_MS),
         'heartbeat_interval_ms': args_config.get('heartbeat_interval_ms', DEFAULT_HEARTBEAT_INTERVAL_MS),
+        'max_poll_records': args_config.get('max_poll_records', DEFAULT_MAX_POLL_RECORDS),
         'max_poll_interval_ms': args_config.get('max_poll_interval_ms', DEFAULT_MAX_POLL_INTERVAL_MS),
         'encoding': args_config.get('encoding', DEFAULT_ENCODING),
         'local_store_dir': args_config.get('local_store_dir', DEFAULT_LOCAL_STORE_DIR)
